# hello_universe

## 1. About
<b>hello_universe</b> is a rookie pypi package that just prints "Hello Universe"  
The main purpose of this project was to get familiar with the purpose of creating and publishing a pypi package.

## 2. Use the package



